@@ -1,6 +1,9 @@
 import requests
 import re
 from bs4 import BeautifulSoup
+import logging
+
+log = logging.getLogger()
 
 
 def finish(owncloud_url, login, password):
@@ -10,6 +13,8 @@ def finish(owncloud_url, login, password):
 
     index_url = get_index_url(owncloud_url)
 
+    log.debug("will finish setup using: %s", index_url)
+
     response = requests.post(index_url,
                              data={
                                  'install': 'true', 'adminlogin': login,
